@@ -8,8 +8,7 @@ from . import LUTRON_CASETA_SMARTBRIDGE
 _LOGGER = logging.getLogger(__name__)
 
 
-async def async_setup_platform(
-        hass, config, async_add_entities, discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up the Lutron Caseta lights."""
     devs = []
     bridge = hass.data[LUTRON_CASETA_SMARTBRIDGE]
@@ -26,8 +25,8 @@ class LutronCasetaScene(Scene):
 
     def __init__(self, scene, bridge):
         """Initialize the Lutron Caseta scene."""
-        self._scene_name = scene['name']
-        self._scene_id = scene['scene_id']
+        self._scene_name = scene["name"]
+        self._scene_id = scene["scene_id"]
         self._bridge = bridge
 
     @property
