@@ -1,19 +1,19 @@
 """Support for Songpal-enabled (Sony) media devices."""
 import asyncio
-import logging
 from collections import OrderedDict
+import logging
 
-import voluptuous as vol
 from songpal import (
+    ConnectChange,
+    ContentChange,
     Device,
+    PowerChange,
     SongpalException,
     VolumeChange,
-    ContentChange,
-    PowerChange,
-    ConnectChange,
 )
+import voluptuous as vol
 
-from homeassistant.components.media_player import MediaPlayerDevice, PLATFORM_SCHEMA
+from homeassistant.components.media_player import PLATFORM_SCHEMA, MediaPlayerDevice
 from homeassistant.components.media_player.const import (
     SUPPORT_SELECT_SOURCE,
     SUPPORT_TURN_OFF,
@@ -25,9 +25,9 @@ from homeassistant.components.media_player.const import (
 from homeassistant.const import (
     ATTR_ENTITY_ID,
     CONF_NAME,
+    EVENT_HOMEASSISTANT_STOP,
     STATE_OFF,
     STATE_ON,
-    EVENT_HOMEASSISTANT_STOP,
 )
 from homeassistant.exceptions import PlatformNotReady
 import homeassistant.helpers.config_validation as cv
