@@ -1,17 +1,18 @@
 """Support for Toon van Eneco devices."""
+from functools import partial
 import logging
 from typing import Any, Dict
-from functools import partial
 
+from toonapilib import Toon
 import voluptuous as vol
 
+from homeassistant.const import CONF_PASSWORD, CONF_SCAN_INTERVAL, CONF_USERNAME
 from homeassistant.core import callback
-from homeassistant.const import CONF_PASSWORD, CONF_USERNAME, CONF_SCAN_INTERVAL
 from homeassistant.helpers import config_validation as cv, device_registry as dr
+from homeassistant.helpers.dispatcher import async_dispatcher_connect, dispatcher_send
 from homeassistant.helpers.entity import Entity
-from homeassistant.helpers.typing import ConfigType, HomeAssistantType
 from homeassistant.helpers.event import async_track_time_interval
-from homeassistant.helpers.dispatcher import dispatcher_send, async_dispatcher_connect
+from homeassistant.helpers.typing import ConfigType, HomeAssistantType
 
 from . import config_flow  # noqa: F401
 from .const import (
@@ -19,10 +20,10 @@ from .const import (
     CONF_CLIENT_SECRET,
     CONF_DISPLAY,
     CONF_TENANT,
+    DATA_TOON,
     DATA_TOON_CLIENT,
     DATA_TOON_CONFIG,
     DATA_TOON_UPDATED,
-    DATA_TOON,
     DEFAULT_SCAN_INTERVAL,
     DOMAIN,
 )
@@ -63,7 +64,6 @@ async def async_setup(hass: HomeAssistantType, config: ConfigType) -> bool:
 
 async def async_setup_entry(hass: HomeAssistantType, entry: ConfigType) -> bool:
     """Set up Toon from a config entry."""
-    from toonapilib import Toon
 
     conf = hass.data.get(DATA_TOON_CONFIG)
 
