@@ -126,6 +126,9 @@ class RawUPnPIGDSensor(UpnpSensor):
     @property
     def state(self) -> str:
         """Return the state of the device."""
+        if self._state is None:
+            return None
+
         return format(self._state, "d")
 
     @property
@@ -154,7 +157,7 @@ class PerSecondUPnPIGDSensor(UpnpSensor):
     """Abstract representation of a X Sent/Received per second sensor."""
 
     def __init__(self, device, direction):
-        """Initializer."""
+        """Initialize sensor."""
         super().__init__(device)
         self._direction = direction
 
@@ -189,7 +192,7 @@ class PerSecondUPnPIGDSensor(UpnpSensor):
     @property
     def unit_of_measurement(self) -> str:
         """Return the unit of measurement of this entity, if any."""
-        return f"{self.unit}/sec"
+        return f"{self.unit}/s"
 
     def _is_overflowed(self, new_value) -> bool:
         """Check if value has overflowed."""
@@ -222,7 +225,7 @@ class KBytePerSecondUPnPIGDSensor(PerSecondUPnPIGDSensor):
     @property
     def unit(self) -> str:
         """Get unit we are measuring in."""
-        return "kbyte"
+        return "kB"
 
     async def _async_fetch_value(self) -> float:
         """Fetch value from device."""
