@@ -62,4 +62,35 @@ class Shade(ZigbeeChannel):
 class WindowCovering(ZigbeeChannel):
     """Window channel."""
 
-    pass
+    _value_attribute = 8
+    REPORT_CONFIG = (
+        {"attr": "current_position_lift_percentage", "config": REPORT_CONFIG_IMMEDIATE},
+    )
+
+    async def async_update(self):
+        """Retrieve latest state."""
+        result = await self.get_attribute_value(
+            "current_position_lift_percentage", from_cache=False
+        )
+        self.debug("read current position: %s", result)
+
+        async_dispatcher_send(
+            self._zha_device.hass, f"{self.unique_id}_{SIGNAL_ATTR_UPDATED}", result
+        )
+
+    @callback
+    def attribute_updated(self, attrid, value):
+        """Handle attribute update from window_covering cluster."""
+        attr_name = self.cluster.attributes.get(attrid, [attrid])[0]
+        self.debug(
+            "Attribute report '%s'[%s] = %s", self.cluster.name, attr_name, value
+        )
+        if attrid == self._value_attribute:
+            async_dispatcher_send(
+                self._zha_device.hass, f"{self.unique_id}_{SIGNAL_ATTR_UPDATED}", value
+            )
+
+    async def async_initialize(self, from_cache):
+        """Initialize channel."""
+        await self.get_attribute_value(self._value_attribute, from_cache=from_cache)
+        await super().async_initialize(from_cache)
