@@ -1,12 +1,12 @@
 """Template helper methods for rendering strings with Home Assistant data."""
 import base64
+from datetime import datetime
+from functools import wraps
 import json
 import logging
 import math
 import random
 import re
-from datetime import datetime
-from functools import wraps
 from typing import Any, Dict, Iterable, List, Optional, Union
 
 import jinja2
@@ -30,7 +30,6 @@ from homeassistant.loader import bind_hass
 from homeassistant.util import convert, dt as dt_util, location as loc_util
 from homeassistant.util.async_ import run_callback_threadsafe
 
-
 # mypy: allow-untyped-calls, allow-untyped-defs
 # mypy: no-check-untyped-defs, no-warn-return-any
 
@@ -329,7 +328,7 @@ class AllStates:
             if not valid_entity_id(name):
                 raise TemplateError(f"Invalid entity ID '{name}'")
             return _get_state(self._hass, name)
-        if not valid_entity_id(name + ".entity"):
+        if not valid_entity_id(f"{name}.entity"):
             raise TemplateError(f"Invalid domain name '{name}'")
         return DomainStates(self._hass, name)
 
@@ -452,7 +451,7 @@ class TemplateState(State):
         """Representation of Template State."""
         state = object.__getattribute__(self, "_access_state")()
         rep = state.__repr__()
-        return "<template " + rep[1:]
+        return f"<template {rep[1:]}"
 
 
 def _collect_state(hass, entity_id):
@@ -616,7 +615,7 @@ def distance(hass, *args):
 
             if latitude is None or longitude is None:
                 _LOGGER.warning(
-                    "Distance:Unable to process latitude and " "longitude: %s, %s",
+                    "Distance:Unable to process latitude and longitude: %s, %s",
                     value,
                     value_2,
                 )
